summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--morphlib/remoteartifactcache.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/morphlib/remoteartifactcache.py b/morphlib/remoteartifactcache.py
index e2101b5d..ecbb7d3a 100644
--- a/morphlib/remoteartifactcache.py
+++ b/morphlib/remoteartifactcache.py
@@ -29,8 +29,9 @@ class GetError(cliapp.AppException):
def __init__(self, cache, artifact):
cliapp.AppException.__init__(
- self, 'Failed to get the artifact %s from the '
- 'artifact cache %s' % (artifact, cache))
+ self, 'Failed to get the artifact %s with cache key %s '
+ 'from the artifact cache %s' %
+ (artifact, artifact.cache_key, cache))
class GetArtifactMetadataError(cliapp.AppException):